<?php
namespace AcademyQuizzes\Classes;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
/**
 * Quiz
 *  - quiz_question_insert
 *  - get_quiz_questions
 *  - get_quiz_question
 *  - get_questions_by_quid_id
 *  - get_question_settings_by_quiz_id
 *  - get_total_questions_marks_by_quiz_id
 *  - quiz_attempt_insert
 *  - get_quiz_attempts
 *  - get_quiz_attempt
 *  - get_quiz_answer
 *  - get_quiz_all_answer_title_by_ids
 *  - get_quiz_answers_by_question_id
 *  - quiz_answer_insert
 *  - get_quiz_total_correct_answer_by_question_id
 *  - get_quiz_total_answer_by_question_id
 *  - get_total_quiz_attempt_correct_answers
 *  - is_quiz_correct_answer
 *  - quiz_attempt_answer_insert
 *  - get_quiz_attempt_answers_earned_marks
 *  - get_quiz_attempt_details
 * - delete_quiz_attempt
 *  - delete_question
 *  - delete_answer
 *  - get_total_number_of_quizzes
 *  - get_total_number_of_quizzes_by_instructor_id
 *  - is_required_manually_reviewed
 *  - get_multi_choose_quiz_correct_answer
 *  - get_total_number_of_attempts
 */
class Query {
	public static function quiz_question_insert( $postarr ) {
		if ( ! is_array( $postarr ) ) {
			return null;
		}

		global $wpdb;
		$defaults = array(
			'quiz_id'               => '',
			'question_title'        => '',
			'question_name'         => '',
			'question_content'      => '',
			'question_status'       => 'publish',
			'question_level'        => '',
			'question_type'         => '',
			'question_score'        => 0,
			'question_settings'     => '',
			'question_order'        => 0,
			'question_created_at'   => current_time( 'mysql' ),
			'question_updated_at' => current_time( 'mysql' ),
		);

		$question_arr = wp_parse_args( $postarr, $defaults );

		// Are we updating or creating?
		$question_ID = 0;
		$update    = false;

		if ( ! empty( $postarr['question_id'] ) ) {
			$question_ID = $postarr['question_id'];
			$update    = true;
			unset( $question_arr['question_id'] );
			$question_arr['question_updated_at'] = current_time( 'mysql' );
		}

		// post insert will be here
		$table_name = $wpdb->prefix . 'academy_quiz_questions';
		if ( $update ) {
			$wpdb->update(
				$table_name,
				$question_arr,
				array( 'question_id' => $question_ID ),
				array(
					'%d',
					'%s',
					'%s',
					'%s',
					'%s',
					'%s',
					'%s',
					'%f',
					'%s',
					'%d',
					'%s',
					'%s',
				),
				array( '%d' )
			);
			return $question_ID;
		} else {
			$wpdb->insert(
				$table_name,
				array(
					'quiz_id' => $question_arr['quiz_id'],
					'question_title' => $question_arr['question_title'],
					'question_name' => $question_arr['question_name'],
					'question_content' => $question_arr['question_content'],
					'question_status' => $question_arr['question_status'],
					'question_level' => $question_arr['question_level'],
					'question_type' => $question_arr['question_type'],
					'question_score' => $question_arr['question_score'],
					'question_settings'     => $question_arr['question_settings'],
					'question_order' => $question_arr['question_order'],
					'question_created_at' => $question_arr['question_created_at'],
					'question_updated_at' => $question_arr['question_updated_at'],
				),
				array(
					'%d',
					'%s',
					'%s',
					'%s',
					'%s',
					'%s',
					'%s',
					'%f',
					'%s',
					'%d',
					'%s',
					'%s',
				)
			);
			return $wpdb->insert_id;
		}//end if
		return null;
	}
	public static function get_quiz_questions( $args ) {
		global $wpdb;
		$defaults = array(
			'limit' => 10,
			'offset' => 0,
		);
		$args = wp_parse_args( $args, $defaults );
		return $wpdb->get_results(
			$wpdb->prepare(
				"SELECT * FROM {$wpdb->prefix}academy_quiz_questions ORDER BY question_created_at DESC LIMIT %d, %d;",
				$args['offset'],
				$args['limit']
			),
			OBJECT
		);
	}
	public static function get_quiz_question( $ID ) {
		global $wpdb;
		$question   = $wpdb->get_results( $wpdb->prepare( "SELECT * FROM {$wpdb->prefix}academy_quiz_questions WHERE question_id=%d", $ID ), OBJECT );
		return current( $question );
	}

	public static function get_questions_by_quid_id( $ID, $order = 'rand' ) {
		global $wpdb;
		$results = [];
		switch ( $order ) {
			case 'rand':
				$results = $wpdb->get_results(
					$wpdb->prepare(
						"SELECT * FROM {$wpdb->prefix}academy_quiz_questions WHERE quiz_id=%d ORDER BY RAND()",
						$ID
					),
					OBJECT
				);
				break;

			case 'ASC':
				$results = $wpdb->get_results(
					$wpdb->prepare(
						"SELECT * FROM {$wpdb->prefix}academy_quiz_questions WHERE quiz_id=%d ORDER BY question_created_at ASC;",
						$ID
					),
					OBJECT
				);
				break;

			case 'DESC':
				$results = $wpdb->get_results(
					$wpdb->prepare(
						"SELECT * FROM {$wpdb->prefix}academy_quiz_questions WHERE quiz_id=%d ORDER BY question_created_at DESC;",
						$ID
					),
					OBJECT
				);
				break;

			default:
				$results = $wpdb->get_results(
					$wpdb->prepare(
						"SELECT * FROM {$wpdb->prefix}academy_quiz_questions WHERE quiz_id=%d ORDER BY question_order DESC;",
						$ID
					),
					OBJECT
				);
				break;
		}//end switch
		return $results;
	}

	public static function get_question_settings_by_quiz_id( $ID ) {
		return [
			'quiz_time' => (int) get_post_meta( $ID, 'academy_quiz_time', true ),
			'quiz_time_unit' => get_post_meta( $ID, 'academy_quiz_time_unit', true ),
			'quiz_hide_quiz_time' => (bool) get_post_meta( $ID, 'academy_quiz_hide_quiz_time', true ),
			'quiz_feedback_mode' => get_post_meta( $ID, 'academy_quiz_feedback_mode', true ),
			'quiz_passing_grade' => (int) get_post_meta( $ID, 'academy_quiz_passing_grade', true ),
			'quiz_max_questions_for_answer' => (int) get_post_meta( $ID, 'academy_quiz_max_questions_for_answer', true ),
			'quiz_max_attempts_allowed' => (int) get_post_meta( $ID, 'academy_quiz_max_attempts_allowed', true ),
			'quiz_auto_start' => (bool) get_post_meta( $ID, 'academy_quiz_auto_start', true ),
			'quiz_questions_order' => get_post_meta( $ID, 'academy_quiz_questions_order', true ),
			'quiz_hide_question_number' => (bool) get_post_meta( $ID, 'academy_quiz_hide_question_number', true ),
			'quiz_short_answer_characters_limit' => (int) get_post_meta( $ID, 'academy_quiz_short_answer_characters_limit', true ),
		];
	}

	public static function get_total_questions_marks_by_quiz_id( $ID ) {
		global $wpdb;
		$questions_marks = $wpdb->get_results(
			$wpdb->prepare(
				"SELECT sum(question_score) as total_marks FROM {$wpdb->prefix}academy_quiz_questions WHERE quiz_id=%d;",
				$ID
			),
			OBJECT
		);
		return (float) current( $questions_marks )->total_marks;
	}

	public static function quiz_attempt_insert( $postarr ) {
		if ( ! is_array( $postarr ) ) {
			return null;
		}

		global $wpdb;
		$defaults = array(
			'course_id'       => '',
			'quiz_id'        => '',
			'user_id'         => get_current_user_id(),
			'total_questions'      => '',
			'total_answered_questions'       => '',
			'total_marks'        => '',
			'earned_marks'         => '',
			'attempt_info'        => '',
			'attempt_status'     => 'pending',
			'attempt_ip'        => \Academy\Helper::get_client_ip_address(),
			'attempt_started_at'   => current_time( 'mysql' ),
			'attempt_ended_at' => current_time( 'mysql' ),
		);

		$attempt = wp_parse_args( $postarr, $defaults );

		// Are we updating or creating?
		$attempt_id = 0;
		$update    = false;

		if ( ! empty( $postarr['attempt_id'] ) ) {
			$attempt_id = $postarr['attempt_id'];
			$update    = true;
			unset( $attempt['attempt_id'] );
			$attempt['attempt_ended_at'] = current_time( 'mysql' );
		}

		// post insert will be here
		$table_name = $wpdb->prefix . 'academy_quiz_attempts';
		if ( $update ) {
			$wpdb->update(
				$table_name,
				$attempt,
				array( 'attempt_id' => $attempt_id ),
				array(
					'%d',
					'%d',
					'%d',
					'%d',
					'%d',
					'%f',
					'%f',
					'%s',
					'%s',
					'%s',
					'%s',
					'%s',
				),
				array( '%d' )
			);
			return $attempt_id;
		} else {
			$wpdb->insert(
				$table_name,
				array(
					'course_id' => $attempt['course_id'],
					'quiz_id' => $attempt['quiz_id'],
					'user_id' => $attempt['user_id'],
					'total_questions' => $attempt['total_questions'],
					'total_answered_questions' => $attempt['total_answered_questions'],
					'total_marks' => $attempt['total_marks'],
					'earned_marks' => $attempt['earned_marks'],
					'attempt_info' => $attempt['attempt_info'],
					'attempt_status'     => $attempt['attempt_status'],
					'attempt_ip' => $attempt['attempt_ip'],
					'attempt_started_at' => $attempt['attempt_started_at'],
					'attempt_ended_at' => $attempt['attempt_ended_at']
				),
				array(
					'%d',
					'%d',
					'%d',
					'%d',
					'%d',
					'%f',
					'%f',
					'%s',
					'%s',
					'%s',
					'%s',
					'%s'
				)
			);
			return $wpdb->insert_id;
		}//end if
		return null;
	}

	public static function update_quiz_attempt_by_manual_review( $postarr ) {
		if ( ! is_array( $postarr ) ) {
			return null;
		}

		global $wpdb;
		$defaults = array(
			'course_id'       => '',
			'quiz_id'        => '',
			'user_id'         => '',
			'total_questions'      => '',
			'total_answered_questions'       => '',
			'total_marks'        => '',
			'earned_marks'         => '',
			'attempt_info'        => '',
			'attempt_status'        => '',
			'attempt_ip'            => '',
			'attempt_started_at'        => '',
			'attempt_ended_at'        => '',
			'is_manually_reviewed' => 1,
			'manually_reviewed_at' => current_time( 'mysql' ),
		);

		$attempt = wp_parse_args( $postarr, $defaults );

		$attempt_id = $attempt['attempt_id'];
		unset( $attempt['attempt_id'] );

		// post insert will be here
		$table_name = $wpdb->prefix . 'academy_quiz_attempts';

		$wpdb->update(
			$table_name,
			$attempt,
			array( 'attempt_id' => $attempt_id ),
			array(
				'%d',
				'%d',
				'%d',
				'%d',
				'%d',
				'%f',
				'%f',
				'%s',
				'%s',
				'%s',
				'%s',
				'%s',
				'%d',
				'%s',
			),
			array( '%d' )
		);
		return $attempt_id;
	}

	public static function get_quiz_attempts( $args ) {
		global $wpdb;
		$defaults = array(
			'per_page' => 10,
			'offset' => 0,
			'quiz_id' => '',
			'user_id' => get_current_user_id()
		);
		$args = wp_parse_args( $args, $defaults );
		if ( ! empty( $args['quiz_id'] ) ) {
			return $wpdb->get_results(
				$wpdb->prepare(
					"SELECT attempt_id, course_id, quiz_id, user_id, total_questions, total_answered_questions, total_marks, earned_marks, attempt_info, attempt_status, attempt_ip, attempt_started_at, attempt_ended_at,  
						(select COUNT(attempt_answer_id) from {$wpdb->prefix}academy_quiz_attempt_answers as attempt_answers where attempt_answers.attempt_id = {$wpdb->prefix}academy_quiz_attempts.attempt_id AND attempt_answers.is_correct=1) as total_correct_answer 
					FROM {$wpdb->prefix}academy_quiz_attempts WHERE quiz_id=%d AND user_id=%d ORDER BY attempt_started_at DESC LIMIT %d, %d;",
					$args['quiz_id'],
					$args['user_id'],
					$args['offset'],
					$args['per_page']
				),
				OBJECT
			);
		}

		if ( current_user_can( 'manage_options' ) ) {
			return $wpdb->get_results(
				$wpdb->prepare(
					"SELECT attempt_id, course_id, quiz_id, user_id, total_questions, total_answered_questions, total_marks, earned_marks, attempt_info, attempt_status, attempt_ip, attempt_started_at, attempt_ended_at,  
						(select COUNT(attempt_answer_id) from {$wpdb->prefix}academy_quiz_attempt_answers as attempt_answers where attempt_answers.attempt_id = {$wpdb->prefix}academy_quiz_attempts.attempt_id AND attempt_answers.is_correct=1) as total_correct_answer 
					FROM {$wpdb->prefix}academy_quiz_attempts ORDER BY attempt_started_at DESC LIMIT %d, %d;",
					$args['offset'],
					$args['per_page']
				),
				OBJECT
			);
		}

		if ( current_user_can( 'manage_academy_instructor' ) ) {
			$courseIds = \Academy\Helper::get_course_ids_by_instructor_id( get_current_user_id() );
			return $wpdb->get_results(
				$wpdb->prepare(
					"SELECT attempt_id, course_id, quiz_id, user_id, total_questions, total_answered_questions, total_marks, earned_marks, attempt_info, attempt_status, attempt_ip, attempt_started_at, attempt_ended_at,  
						(select COUNT(attempt_answer_id) from {$wpdb->prefix}academy_quiz_attempt_answers as attempt_answers where attempt_answers.attempt_id = {$wpdb->prefix}academy_quiz_attempts.attempt_id AND attempt_answers.is_correct=1) as total_correct_answer 
					FROM {$wpdb->prefix}academy_quiz_attempts WHERE course_id IN (%s) ORDER BY attempt_started_at DESC LIMIT %d, %d;",
					implode( ',', $courseIds ),
					$args['offset'],
					$args['per_page']
				),
				OBJECT
			);
		}
		return false;
	}

	public static function get_quiz_attempt( $ID ) {
		global $wpdb;
		$attempt   = $wpdb->get_results( $wpdb->prepare( "SELECT * FROM {$wpdb->prefix}academy_quiz_attempts WHERE attempt_id=%d", $ID ), OBJECT );
		return current( $attempt );
	}

	public static function get_quiz_answer( $ID ) {
		global $wpdb;
		$answer   = $wpdb->get_results( $wpdb->prepare( "SELECT answer_id, quiz_id, answer_title, answer_content, image_id, view_format, answer_order, answer_created_at, answer_updated_at FROM {$wpdb->prefix}academy_quiz_answers WHERE answer_id=%d", $ID ), OBJECT );
		return current( $answer );
	}

	public static function get_quiz_all_answer_title_by_ids( $IDs ) {
		global $wpdb;
		$implode_ids_placeholder = implode( ', ', array_fill( 0, count( $IDs ), '%d' ) );
		// phpcs:disable
		$answer   = $wpdb->get_results( $wpdb->prepare( "SELECT answer_title FROM {$wpdb->prefix}academy_quiz_answers WHERE answer_id IN($implode_ids_placeholder)", $IDs ), OBJECT );
		// phpcs:enable
		return $answer;
	}

	public static function get_quiz_answers_by_question_id( $question_id, $question_type ) {
		global $wpdb;
		return $wpdb->get_results(
			$wpdb->prepare(
				"SELECT answer_id, quiz_id, answer_title, image_id, view_format, answer_order, answer_created_at, answer_updated_at  FROM {$wpdb->prefix}academy_quiz_answers WHERE question_id=%d AND question_type=%s",
				$question_id,
				$question_type
			),
			OBJECT
		);
	}

	public static function quiz_answer_insert( $postarr ) {
		if ( ! is_array( $postarr ) ) {
			return null;
		}

		global $wpdb;
		$defaults = array(
			'quiz_id'               => '',
			'question_id'               => '',
			'question_type'               => '',
			'answer_title'        => '',
			'answer_content'         => '',
			'is_correct'      => '',
			'image_id'       => '',
			'view_format'        => '',
			'answer_order'         => '',
			'answer_created_at'   => current_time( 'mysql' ),
			'answer_updated_at' => current_time( 'mysql' ),
		);

		$question_arr = wp_parse_args( $postarr, $defaults );

		// Are we updating or creating?
		$answer_ID = 0;
		$update    = false;

		if ( ! empty( $postarr['answer_id'] ) ) {
			$answer_ID = $postarr['answer_id'];
			$update    = true;
			unset( $question_arr['answer_id'] );
			$question_arr['answer_updated_at'] = current_time( 'mysql' );
		}

		// post insert will be here
		$table_name = $wpdb->prefix . 'academy_quiz_answers';
		if ( $update ) {
			$wpdb->update(
				$table_name,
				$question_arr,
				array( 'answer_id' => $answer_ID ),
				array(
					'%d',
					'%d',
					'%s',
					'%s',
					'%s',
					'%d',
					'%d',
					'%s',
					'%d',
					'%s',
					'%s',
				),
				array( '%d' )
			);
			return $answer_ID;
		} else {
			$wpdb->insert(
				$table_name,
				array(
					'quiz_id' => $question_arr['quiz_id'],
					'question_id' => $question_arr['question_id'],
					'question_type' => $question_arr['question_type'],
					'answer_title' => $question_arr['answer_title'],
					'answer_content' => $question_arr['answer_content'],
					'is_correct' => $question_arr['is_correct'],
					'image_id' => $question_arr['image_id'],
					'view_format' => $question_arr['view_format'],
					'answer_order' => $question_arr['answer_order'],
					'answer_created_at' => $question_arr['answer_created_at'],
					'answer_updated_at' => $question_arr['answer_updated_at']
				),
				array(
					'%d',
					'%d',
					'%s',
					'%s',
					'%s',
					'%d',
					'%d',
					'%s',
					'%d',
					'%s',
					'%s'
				)
			);
			return $wpdb->insert_id;
		}//end if
		return null;
	}

	public static function get_quiz_total_correct_answer_by_question_id( $ID ) {
		global $wpdb;
		$answers   = $wpdb->get_results( $wpdb->prepare( "SELECT is_correct FROM {$wpdb->prefix}academy_quiz_answers WHERE question_id=%d AND is_correct=%d", $ID, 1 ), OBJECT );
		return count( $answers );
	}

	public static function get_quiz_total_answer_by_question_id( $ID ) {
		global $wpdb;
		$total_questions = $wpdb->get_var( $wpdb->prepare( "SELECT COUNT(question_id) FROM {$wpdb->prefix}academy_quiz_answers WHERE question_id=%d", $ID ) );
		return $total_questions;
	}

	public static function get_total_quiz_attempt_correct_answers( $ID ) {
		global $wpdb;
		$correct_answers = $wpdb->get_var( $wpdb->prepare( "SELECT COUNT(is_correct) FROM {$wpdb->prefix}academy_quiz_attempt_answers WHERE attempt_id=%d AND is_correct=%d", $ID, 1 ) );
		return (int) $correct_answers;
	}

	public static function is_image_answer_quiz_correct_answer( $IDs, $question_id = '' ) {
		global $wpdb;
		if ( is_array( $IDs ) ) {
			$correct_answer_count = 0;
			foreach ( $IDs as $ID => $value ) {
				$correct_answer_count  += $wpdb->get_var( $wpdb->prepare( "SELECT COUNT(answer_id) FROM {$wpdb->prefix}academy_quiz_answers WHERE answer_id=%d AND answer_title=%s", $ID, $value ) );
			}
			$total_correct_answer = (int) self::get_quiz_total_answer_by_question_id( $question_id );
			return ( $total_correct_answer === $correct_answer_count ? true : false );
		}
		return false;
	}

	public static function is_fill_in_the_blanks_quiz_correct_answer( $given_answer_args, $question_id = '' ) {
		global $wpdb;
		if ( is_array( $given_answer_args ) ) {
			$correct_answer_count = 0;
			foreach ( $given_answer_args as $given_answer ) {
				$correct_answer_count += $wpdb->get_var( $wpdb->prepare( "SELECT count(answer_id) FROM {$wpdb->prefix}academy_quiz_answers WHERE question_id=%d AND answer_content LIKE %s", $question_id, '%' . $wpdb->esc_like( $given_answer ) . '%' ) );
			}
			return ( count( $given_answer_args ) === $correct_answer_count ? true : false );
		}
		return false;
	}

	public static function is_quiz_correct_answer( $IDs, $question_id = '' ) {
		global $wpdb;
		if ( is_array( $IDs ) ) {
			$correct_answer_count = 0;
			$has_wrong_answer = false;
			foreach ( $IDs as $ID ) {
				$answers   = $wpdb->get_results( $wpdb->prepare( "SELECT is_correct FROM {$wpdb->prefix}academy_quiz_answers WHERE answer_id=%d", $ID ), OBJECT );
				if ( (bool) current( $answers )->is_correct === true ) {
					$correct_answer_count++;
				} else {
					$has_wrong_answer = true;
					break;
				}
			}
			if ( $has_wrong_answer ) {
				return false;
			}
			$total_correct_answer = (int) self::get_quiz_total_correct_answer_by_question_id( $question_id );
			return ( $total_correct_answer === $correct_answer_count ? true : false );
		}
		$answers   = $wpdb->get_results( $wpdb->prepare( "SELECT is_correct FROM {$wpdb->prefix}academy_quiz_answers WHERE answer_id=%d", $IDs ), OBJECT );
		return (bool) current( $answers )->is_correct;
	}

	public static function get_quiz_attempt_answer( $ID ) {
		global $wpdb;
		$attemp_answer   = $wpdb->get_results( $wpdb->prepare( "SELECT * FROM {$wpdb->prefix}academy_quiz_attempt_answers WHERE attempt_answer_id=%d", $ID ), OBJECT );
		return current( $attemp_answer );
	}

	public static function quiz_attempt_answer_insert( $postarr ) {
		if ( ! is_array( $postarr ) ) {
			return null;
		}

		global $wpdb;
		$defaults = array(
			'user_id'            => get_current_user_id(),
			'quiz_id'            => '',
			'question_id'        => '',
			'attempt_id'         => '',
			'answer'             => '',
			'question_mark'      => '',
			'achieved_mark'      => '',
			'minus_mark'         => '',
			'is_correct'         => '',
		);

		$attempt = wp_parse_args( $postarr, $defaults );
		$table_name = $wpdb->prefix . 'academy_quiz_attempt_answers';

		// Are we updating or creating?
		$attempt_answer_id = 0;
		$update    = false;

		if ( ! empty( $postarr['attempt_answer_id'] ) ) {
			$attempt_answer_id = $postarr['attempt_answer_id'];
			$update    = true;
			unset( $attempt['attempt_answer_id'] );
		}
		// update attempt answer
		if ( $update ) {
			$wpdb->update(
				$table_name,
				$attempt,
				array( 'attempt_answer_id' => $attempt_answer_id ),
				array(
					'%d',
					'%d',
					'%d',
					'%d',
					'%s',
					'%f',
					'%f',
					'%f',
					'%d',
				),
				array( '%d' )
			);
			return $attempt_answer_id;
		}
		// insert attempt answer
		$wpdb->insert(
			$table_name,
			array(
				'user_id' => $attempt['user_id'],
				'quiz_id' => $attempt['quiz_id'],
				'question_id' => $attempt['question_id'],
				'attempt_id' => $attempt['attempt_id'],
				'answer' => $attempt['answer'],
				'question_mark' => $attempt['question_mark'],
				'achieved_mark' => $attempt['achieved_mark'],
				'minus_mark' => $attempt['minus_mark'],
				'is_correct' => $attempt['is_correct'],
			),
			array(
				'%d',
				'%d',
				'%d',
				'%d',
				'%s',
				'%f',
				'%f',
				'%f',
				'%d',
			)
		);
		return $wpdb->insert_id;
	}

	public static function get_quiz_attempt_answers_earned_marks( $user_id, $attempt_id ) {
		global $wpdb;
		$earned_marks = $wpdb->get_results(
			$wpdb->prepare(
				"SELECT sum(achieved_mark) as total_marks FROM {$wpdb->prefix}academy_quiz_attempt_answers WHERE user_id=%d AND attempt_id=%d;",
				$user_id,
				$attempt_id
			),
			OBJECT
		);
		return (float) current( $earned_marks )->total_marks;
	}

	public static function get_quiz_attempt_details( $attempt_id, $user_id ) {
		global $wpdb;
		return $wpdb->get_results($wpdb->prepare( "SELECT
            attempt_answers.attempt_answer_id, 
            attempt_answers.attempt_id, 
            attempt_answers.user_id, 
            attempt_answers.question_id,
			attempt_answers.is_correct, 
            attempt_answers.answer as given_answer,
            quiz_answers.answer_title as correct_answer,
            quiz_answers.answer_content,
            quiz_answers.answer_id,
			quiz_answers.is_correct as is_correct_answer,
            quiz_questions.quiz_id,
            quiz_questions.question_title, 
            quiz_questions.question_type
            FROM {$wpdb->prefix}academy_quiz_attempt_answers as attempt_answers 
            LEFT JOIN {$wpdb->prefix}academy_quiz_questions as quiz_questions ON attempt_answers.question_id = quiz_questions.question_id
            LEFT JOIN {$wpdb->prefix}academy_quiz_answers as quiz_answers ON attempt_answers.question_id = quiz_answers.question_id
            WHERE attempt_answers.attempt_id=%d AND attempt_answers.user_id=%d", $attempt_id, $user_id ), OBJECT );
	}

	public static function delete_quiz_attempt( $attempt_id ) {
		global $wpdb;
		$is_delete_attempts = $wpdb->delete( $wpdb->prefix . 'academy_quiz_attempts', array( 'attempt_id' => $attempt_id ), array( '%d' ) );
		$is_delete_attempt_answers = $wpdb->delete( $wpdb->prefix . 'academy_quiz_attempt_answers', array( 'attempt_id' => $attempt_id ), array( '%d' ) );
		return $is_delete_attempts === $is_delete_attempt_answers;
	}

	public static function delete_question( $question_id ) {
		global $wpdb;
		$is_deleted = $wpdb->delete( $wpdb->prefix . 'academy_quiz_questions', array( 'question_id' => $question_id ), array( '%d' ) );
		$wpdb->delete( $wpdb->prefix . 'academy_quiz_answers', array( 'question_id' => $question_id ), array( '%d' ) );
		$attempt_id = $wpdb->delete( $wpdb->prefix . 'academy_quiz_attempt_answers', array( 'question_id' => $question_id ), array( '%d' ) );
		$wpdb->delete( $wpdb->prefix . 'academy_quiz_attempts', array( 'attempt_id' => $attempt_id ), array( '%d' ) );
		return $is_deleted;
	}

	public static function delete_answer( $answer_id ) {
		global $wpdb;
		return $wpdb->delete( $wpdb->prefix . 'academy_quiz_answers', array( 'answer_id' => $answer_id ), array( '%d' ) );
	}

	public static function get_total_number_of_quizzes() {
		global $wpdb;
		$results = $wpdb->get_var(
			$wpdb->prepare("SELECT COUNT(ID) 
            FROM {$wpdb->posts} 
            WHERE post_type = %s 
            AND post_status = %s", 'academy_quiz', 'publish')
		);
		return (int) $results;
	}
	public static function get_total_number_of_quizzes_by_instructor_id( $instructor_id ) {
		global $wpdb;
		$results = $wpdb->get_var(
			$wpdb->prepare("SELECT COUNT(ID) 
            FROM {$wpdb->posts} 
            WHERE post_type = %s 
            AND post_author = %d
			AND post_status = %s", 'academy_quiz', $instructor_id, 'publish')
		);
		return (int) $results;
	}
	public static function is_required_manually_reviewed( $quiz_id ) {
		global $wpdb;
		$results = $wpdb->get_var(
			$wpdb->prepare(
				"SELECT COUNT(question_id) FROM {$wpdb->prefix}academy_quiz_questions WHERE quiz_id=%d AND question_type=%s;",
				$quiz_id,
				'shortAnswer'
			)
		);
		return (int) $results;
	}
	public static function get_multi_choose_quiz_correct_answer( $question_id ) {
		global $wpdb;
		return $wpdb->get_results( $wpdb->prepare( "SELECT answer_title FROM {$wpdb->prefix}academy_quiz_answers WHERE question_id=%d AND question_type=%s AND is_correct=%d", $question_id, 'multipleChoice', 1 ), OBJECT );
	}
	public static function get_total_number_of_attempts() {
		global $wpdb;
		return $wpdb->get_var( "SELECT COUNT(*) FROM {$wpdb->prefix}academy_quiz_attempts" );
	}
}
