<?php
namespace Academy\Admin;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Academy;
use Academy\Classes\Pages;

class Ajax {

	public static function init() {
		$self = new self();
		add_action( 'wp_ajax_academy/admin/get_admin_menu_items', array( $self, 'get_admin_menu_items' ) );
		add_action( 'wp_ajax_academy/admin/get_analytics', array( $self, 'get_analytics' ) );
		add_action( 'wp_ajax_academy/admin/get_enrolled_students', array( $self, 'get_enrolled_students' ) );
		add_action( 'wp_ajax_academy/admin/get_all_students', array( $self, 'get_all_students' ) );
		// instructor
		add_action( 'wp_ajax_academy/admin/get_all_instructors', array( $self, 'get_all_instructors' ) );
		add_action( 'wp_ajax_academy/admin/update_instructor_status', array( $self, 'update_instructor_status' ) );
		// course slug
		add_action( 'wp_ajax_academy/admin/get_course_slug', array( $self, 'get_course_slug' ) );
		// fetch posts
		add_action( 'wp_ajax_academy/admin/fetch_posts', array( $self, 'fetch_posts' ) );
		add_action( 'wp_ajax_academy/admin/fetch_products', array( $self, 'fetch_products' ) );
		// Addons
		add_action( 'wp_ajax_academy/admin/get_addons_status', array( $self, 'get_addons_status' ) );
		add_action( 'wp_ajax_academy/admin/saved_addons_status', array( $self, 'saved_addons_status' ) );
		// Tools
		add_action( 'wp_ajax_academy/admin/fetch_academy_status', array( $self, 'fetch_academy_status' ) );
		add_action( 'wp_ajax_academy/admin/fetch_academy_pages', array( $self, 'fetch_academy_pages' ) );
		add_action( 'wp_ajax_academy/admin/regenerate_academy_pages', array( $self, 'regenerate_academy_pages' ) );
		// Register
		add_action( 'wp_ajax_academy/admin/register_student', array( $self, 'register_student' ) );
		add_action( 'wp_ajax_academy/admin/register_instructor', array( $self, 'register_instructor' ) );
	}

	public function get_admin_menu_items() {
		check_admin_referer( 'academy_nonce', 'security' );
		$menu_items = wp_json_encode( \Academy\Helper::get_admin_menu_list() );
		wp_send_json_success( $menu_items );
		wp_die();
	}

	public function get_analytics() {
		check_admin_referer( 'academy_nonce', 'security' );
		$analytics = new \Academy\Classes\Analytics();
		wp_send_json_success( $analytics->get_analytics() );
		wp_die();
	}

	public function get_enrolled_students() {
		check_admin_referer( 'academy_nonce', 'security' );
		$total_enrolled_students = \Academy\Helper::get_total_number_of_students();
		wp_send_json_success( array( 'total_enrolled_students' => $total_enrolled_students ) );
		wp_die();
	}




	public function get_all_students() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! current_user_can( 'manage_options' ) ) {
			wp_die();
		}

		$page = ( isset( $_POST['page'] ) ? sanitize_text_field( $_POST['page'] ) : 1 );
		$per_page = ( isset( $_POST['per_page'] ) ? sanitize_text_field( $_POST['per_page'] ) : 10 );
		$search = ( isset( $_POST['search'] ) ? sanitize_text_field( $_POST['search'] ) : '' );
		$offset = ( $page - 1 ) * $per_page;

		$Analytics = new \Academy\Classes\Analytics();
		$total_students = $Analytics->get_total_number_of_students();

		// Set the x-wp-total header
		header( 'x-wp-total: ' . $total_students );

		$students = \Academy\Helper::get_all_students( $offset, $per_page, $search );
		$students = \Academy\Helper::prepare_get_all_students_response( $students );
		wp_send_json_success( $students );
		wp_die();
	}

	public function get_all_instructors() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! current_user_can( 'manage_options' ) ) {
			wp_die();
		}

		$page = ( isset( $_POST['page'] ) ? sanitize_text_field( $_POST['page'] ) : 1 );
		$per_page = ( isset( $_POST['per_page'] ) ? sanitize_text_field( $_POST['per_page'] ) : 10 );
		$offset = ( $page - 1 ) * $per_page;
		$search = ( isset( $_POST['search'] ) ? sanitize_text_field( $_POST['search'] ) : '' );

		$Analytics = new \Academy\Classes\Analytics();
		$total_instructors = $Analytics->get_total_number_of_instructors();

		// Set the x-wp-total header
		header( 'x-wp-total: ' . $total_instructors );

		$instructors = \Academy\Helper::get_all_instructors( $offset, $per_page, $search );
		$results     = \Academy\Helper::prepare_all_instructors_response( $instructors );
		wp_send_json_success( $results );
		wp_die();
	}

	public function update_instructor_status() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! current_user_can( 'manage_options' ) ) {
			wp_die();
		}
		$ID     = ( isset( $_POST['ID'] ) ? intval( sanitize_text_field( $_POST['ID'] ) ) : '' );
		$status = ( isset( $_POST['status'] ) ? $_POST['status'] : '' );

		if ( get_current_user_id() === $ID ) {
			wp_send_json_error( __( 'Same user will be not able to update status', 'academy' ) );
		}

		if ( 'approved' === $status ) {
			\Academy\Helper::set_instructor_role( $ID );
		} elseif ( 'pending' === $status ) {
			\Academy\Helper::pending_instructor_role( $ID );
		} elseif ( 'remove' === $status ) {
			\Academy\Helper::remove_instructor_role( $ID );
		}

		do_action( 'academy/admin/update_instructor_status', $ID, $status );

		$instructors = \Academy\Helper::get_all_instructors();
		$results = \Academy\Helper::prepare_all_instructors_response( $instructors );
		wp_send_json_success( $results );
		wp_die();
	}

	public function get_course_slug() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! current_user_can( 'edit_posts' ) ) {
			wp_die();
		}
		$post_id = ( isset( $_POST['ID'] ) ? sanitize_text_field( $_POST['ID'] ) : '' );
		$title   = isset( $_POST['new_title'] ) ? sanitize_text_field( $_POST['new_title'] ) : '';
		$slug    = isset( $_POST['new_slug'] ) ? sanitize_text_field( $_POST['new_slug'] ) : null;

		wp_send_json_success( Academy\Helper::get_sample_permalink_args( $post_id, $title, $slug ) );
		wp_die();
	}
	public function fetch_posts() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! current_user_can( 'edit_posts' ) ) {
			wp_die();
		}

		$post_type = ( isset( $_POST['postType'] ) ? sanitize_text_field( $_POST['postType'] ) : 'pages' );
		$postId = (int) ( isset( $_POST['postId'] ) ? sanitize_text_field( $_POST['postId'] ) : 0 );

		if ( $postId ) {
			$args    = array(
				'post_type'      => $post_type,
				'p'      => $postId,
			);
		} else {
			$args    = array(
				'post_type'      => $post_type,
				'posts_per_page' => 10,
			);
			$keyword = ( isset( $_POST['keyword'] ) ? sanitize_text_field( $_POST['keyword'] ) : '' );
			if ( ! empty( $keyword ) ) {
				$args['s'] = $keyword;
			}
		}

		$results = array();
		$posts   = get_posts( $args );

		if ( is_array( $posts ) ) {
			foreach ( $posts as $post ) {
				$results[] = array(
					'label' => $post->post_title,
					'value' => $post->ID,
				);
			}
		}

		wp_send_json_success( $results );
	}

	public function fetch_products() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! current_user_can( 'edit_posts' ) ) {
			wp_die();
		}

		global $wpdb;
		$post_type = 'product';
		$paid_course_product_ids = [];
		$productId = (int) sanitize_text_field( $_POST['productId'] );
		$keyword = ( isset( $_POST['keyword'] ) ? sanitize_text_field( $_POST['keyword'] ) : '' );
		$type = ( isset( $_POST['type'] ) ? sanitize_text_field( $_POST['type'] ) : 'single' );

		if ( 'single' === $type ) {
			$args    = array(
				'post_type'      => $post_type,
				'p'      => $productId,
			);
		} else {
			$args    = array(
				'post_type'      => $post_type,
				'posts_per_page' => 10,
			);
			if ( ! empty( $keyword ) ) {
				$args['s'] = $keyword;
			}

			// fetch all paid course product id
			$paid_course_product_ids = $wpdb->get_results($wpdb->prepare(
				"SELECT meta_value FROM {$wpdb->postmeta} postmeta  WHERE postmeta.meta_key = 'academy_course_product_id' AND postmeta.meta_value != %d", 0
			), ARRAY_A);
			$paid_course_product_ids = wp_list_pluck( $paid_course_product_ids, 'meta_value', 'meta_value' );
		}

		$results = array();
		$posts   = get_posts( $args );

		if ( is_array( $posts ) ) {
			foreach ( $posts as $post ) {
				if ( $productId !== (int) $post->ID && isset( $paid_course_product_ids[ $post->ID ] ) ) {
					continue;
				}
				$results[] = array(
					'label' => $post->post_title,
					'value' => $post->ID,
				);
			}
		}

		wp_send_json_success( $results );
	}

	public function get_addons_status() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! current_user_can( 'manage_options' ) ) {
			wp_die();
		}
		$academy_addons = json_decode( get_option( ACADEMY_ADDONS_SETTINGS_NAME, '{}' ) );
		wp_send_json_success( $academy_addons );
	}

	public function saved_addons_status() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! current_user_can( 'manage_options' ) ) {
			wp_die();
		}

		$multi_instructor = ( isset( $_POST['multi_instructor'] ) ? filter_var( sanitize_text_field( $_POST['multi_instructor'] ), FILTER_VALIDATE_BOOLEAN ) : false );
		$quizzes = ( isset( $_POST['quizzes'] ) ? filter_var( sanitize_text_field( $_POST['quizzes'] ), FILTER_VALIDATE_BOOLEAN ) : false );

		$addons = apply_filters('academy/admin/saved_addons_status', array(
			'multi_instructor' => $multi_instructor,
			'quizzes' => $quizzes,
		), $_POST);

		// keep only active addons name
		$addons = array_filter($addons, function( $status ) {
			return true === $status;
		});

		// saved new data
		if ( ! get_option( ACADEMY_ADDONS_SETTINGS_NAME ) ) {
			add_option( ACADEMY_ADDONS_SETTINGS_NAME, wp_json_encode( $addons ) );
			wp_send_json_success( $addons );
		}
		// update existing data
		update_option( ACADEMY_ADDONS_SETTINGS_NAME, wp_json_encode( $addons ) );
		wp_send_json_success( $addons );
	}

	public function fetch_academy_status() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! current_user_can( 'manage_options' ) ) {
			wp_die();
		}

		$tools = new \Academy\Classes\Tools();
		$wordpress = $tools->get_wordpress_environment_status();
		$server = $tools->get_server_environment_status();
		wp_send_json_success( [
			'wordpress' => $wordpress,
			'server' => $server
		] );
	}

	public function fetch_academy_pages() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! current_user_can( 'manage_options' ) ) {
			wp_die();
		}
		$pages = Pages::get_necessary_pages();
		wp_send_json_success( $pages );
	}

	public function regenerate_academy_pages() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! current_user_can( 'manage_options' ) ) {
			wp_die();
		}
		$status = Pages::regenerate_necessary_pages();
		wp_send_json_success( $status );
	}

	public function register_student() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! current_user_can( 'manage_options' ) ) {
			wp_die();
		}

		$first_name = sanitize_text_field( $_POST['first_name'] );
		$last_name = sanitize_text_field( $_POST['last_name'] );
		$username = sanitize_text_field( $_POST['username'] );
		$email = sanitize_text_field( $_POST['email'] );
		$password = sanitize_text_field( $_POST['password'] );

		if ( empty( $username ) ) {
			wp_send_json_error( __( 'You have used an invalid username.', 'academy' ) );
		} elseif ( username_exists( $username ) ) {
			wp_send_json_error( __( 'Invalid username provided or the username already registered.', 'academy' ) );
		}

		if ( empty( $email ) || ! is_email( $email ) ) {
			wp_send_json_error( __( 'Email is missing or Invalid.', 'academy' ) );
		} elseif ( email_exists( $email ) ) {
			wp_send_json_error( __( 'The provided email is already registered with other account. Please login or reset password or use another email.', 'academy' ) );
		}

		$user_data = array(
			'user_login' => $username,
			'user_email' => $email,
			'first_name' => $first_name,
			'last_name'  => $last_name,
			'user_pass'  => $password,
			'role'       => 'academy_student'
		);
		do_action( 'academy/admin/before_register_student', $user_data );

		$user_id = wp_insert_user( $user_data );
		if ( ! is_wp_error( $user_id ) ) {
			update_user_meta( $user_id, 'is_academy_student', \Academy\Helper::get_time() );
			do_action( 'academy/admin/after_register_student', $user_id );
			wp_send_json_success( get_user_by( 'ID', $user_id ) );
		}
		wp_send_json_error( __( 'Failed to add student. try again', 'academy' ) );
	}

	public function register_instructor() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! current_user_can( 'manage_options' ) ) {
			wp_die();
		}

		$first_name = sanitize_text_field( $_POST['first_name'] );
		$last_name = sanitize_text_field( $_POST['last_name'] );
		$username = sanitize_text_field( $_POST['username'] );
		$email = sanitize_text_field( $_POST['email'] );
		$password = sanitize_text_field( $_POST['password'] );

		if ( empty( $username ) ) {
			wp_send_json_error( __( 'You have used an invalid username.', 'academy' ) );
		} elseif ( username_exists( $username ) ) {
			wp_send_json_error( __( 'Invalid username provided or the username already registered.', 'academy' ) );
		}

		if ( empty( $email ) || ! is_email( $email ) ) {
			wp_send_json_error( __( 'Email is missing or Invalid.', 'academy' ) );
		} elseif ( email_exists( $email ) ) {
			wp_send_json_error( __( 'The provided email is already registered with other account. Please login or reset password or use another email.', 'academy' ) );
		}

		$user_data = array(
			'user_login' => $username,
			'user_email' => $email,
			'first_name' => $first_name,
			'last_name'  => $last_name,
			'user_pass'  => $password,
			'role'       => 'academy_instructor'
		);
		do_action( 'academy/admin/before_register_instructor', $user_data );

		$user_id = wp_insert_user( $user_data );
		if ( ! is_wp_error( $user_id ) ) {
			update_user_meta( $user_id, 'is_academy_instructor', \Academy\Helper::get_time() );
			update_user_meta( $user_id, 'academy_instructor_status', 'approved' );
			do_action( 'academy/admin/after_register_instructor', $user_id );
			wp_send_json_success( get_user_by( 'ID', $user_id ) );
		}
		wp_send_json_error( __( 'Failed to add instructor.', 'academy' ) );
	}
}
