<?php
namespace Academy\Admin;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Settings {
	public static function get_settings_saved_data() {
		$settings = get_option( ACADEMY_SETTINGS_NAME );
		if ( $settings ) {
			return json_decode( $settings, true );
		}
		return [];
	}
	public static function get_settings_default_data() {
		return apply_filters('academy/admin/settings_default_data', [
			// general
			'frontend_dashboard_page' => '',
			'is_enabled_academy_login' => true,
			'is_enabled_academy_web_font' => true,
			'course_page' => '',
			'frontend_student_reg_page' => '',
			'is_student_can_upload_files' => true,
			'lessons_topbar_logo' => '',
			'monetization_engine' => 'woocommerce',
			// instructor
			'frontend_instructor_reg_page'      => '',
			'is_show_public_profile'            => true,
			'is_instructor_can_publish_course'  => false,
			'is_instructor_update_course_price' => true,
			// WooCommerce
			'woo_force_login_before_enroll' => true,
			'hide_course_product_from_shop_page' => false,
			'woo_order_auto_complete' => false,
			'is_enabled_fd_link_inside_woo_dashboard' => true,
			'woo_dashboard_fd_link_label' => esc_html__( 'Courses Dashboard', 'academy' ),
			'is_enabled_fd_link_inside_woo_order_page' => true,
			'woo_order_page_fd_link_label' => esc_html__( 'Courses Dashboard', 'academy' ),
			'store_link_inside_frontend_dashboard' => true,
			'store_link_label_inside_frontend_dashboard' => esc_html__( 'Store Dashboard', 'academy' ),
		]);
	}

	public static function save_settings( $form_data = false ) {
		$default_data = self::get_settings_default_data();
		$saved_data = self::get_settings_saved_data();
		$settings_data = wp_parse_args( $saved_data, $default_data );
		if ( $form_data ) {
			$settings_data = wp_parse_args( $form_data, $settings_data );
		}
		// if settings already saved, then update it
		if ( count( $saved_data ) ) {
			return update_option( ACADEMY_SETTINGS_NAME, wp_json_encode( $settings_data ) );
		}
		return add_option( ACADEMY_SETTINGS_NAME, wp_json_encode( $settings_data ) );
	}
}
