<?php
namespace Academy\Classes;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Analytics {

	public function get_analytics() {
		$analytics = [
			'total_courses'          => $this->get_total_number_of_courses(),
			'total_enrolled_courses' => $this->get_total_number_of_enrolled_courses(),
			'total_lessons'          => $this->get_total_number_of_lessons(),
			'total_questions'        => $this->get_total_number_of_questions(),
			'total_instructors'      => $this->get_total_number_of_instructors(),
			'total_students'         => $this->get_total_number_of_students(),
			'total_reviews'          => $this->get_total_number_of_reviews(),
			'enrolled_info'          => $this->get_enrolled_info(),
		];
		return apply_filters( 'academy/get_analytics', $analytics );
	}

	public function get_total_number_of_courses() {
		global $wpdb;
		$results = $wpdb->get_var(
			$wpdb->prepare("SELECT COUNT(ID) 
            FROM {$wpdb->posts} 
            WHERE post_type = %s 
            AND post_status = %s", 'academy_courses', 'publish')
		);
		return (int) $results;
	}

	public function get_total_number_of_enrolled_courses() {
		global $wpdb;
		$results = $wpdb->get_var(
			$wpdb->prepare("SELECT COUNT(ID) 
            FROM {$wpdb->posts} 
            WHERE post_type =%s 
            AND post_status = %s", 'academy_enrolled', 'completed')
		);
		return (int) $results;
	}

	public function get_total_number_of_lessons() {
		global $wpdb;
		$results = $wpdb->get_var(
			$wpdb->prepare("SELECT COUNT(ID) 
            FROM {$wpdb->prefix}academy_lessons
            WHERE lesson_status=%s", 'publish')
		);
		return (int) $results;
	}

	public function get_total_number_of_questions() {
		global $wpdb;
		$results = $wpdb->get_var(
			$wpdb->prepare("SELECT COUNT(comment_ID) 
            FROM {$wpdb->comments}
            WHERE comment_type=%s
            AND comment_approved=%s", 'academy_qa', 'waiting_for_answer')
		);
		return (int) $results;
	}

	public function get_total_number_of_instructors() {
		global $wpdb;
		$results = $wpdb->get_var(
			$wpdb->prepare("SELECT COUNT(umeta_id) 
            FROM {$wpdb->usermeta} 
            WHERE meta_key = %s", 'is_academy_instructor')
		);
		return (int) $results;
	}

	public function get_total_number_of_students() {
		global $wpdb;
		$results = $wpdb->get_var(
			$wpdb->prepare(
				"SELECT COUNT(umeta_id) 
            FROM {$wpdb->usermeta} 
            WHERE meta_key = %s", 'is_academy_student')
		);
		return (int) $results;
	}

	public function get_total_number_of_reviews() {
		global $wpdb;
		$results = $wpdb->get_var(
			$wpdb->prepare("SELECT COUNT(comment_ID) 
            FROM {$wpdb->comments} 
            WHERE comment_type =%s", 'academy_courses')
		);
		return (int) $results;
	}

	public function get_enrolled_info() {
		global $wpdb;
		$from    = gmdate( 'Y-m-d', strtotime( ' - 30 days' ) );
		$to      = gmdate( 'Y-m-d' );
		$results = $wpdb->get_results(
			$wpdb->prepare("SELECT COUNT(ID) as total, DATE(post_date)  as date_format 
            FROM {$wpdb->posts} 
            WHERE post_type = %s 
            AND (post_date BETWEEN %s AND %s )
            GROUP BY date_format
            ORDER BY post_date ASC;", 'academy_enrolled', $from, $to)
		);
		$results = $this->format_query_results_to_chart_data( $from, $to, $results );
		return $results;
	}

	public function format_query_results_to_chart_data( $from, $to, $data ) {
		$datesPeriod        = $this->get_empty_collection_date_by_period( $from, $to );
		$total     = wp_list_pluck( $data, 'total' );
		$queried_date       = wp_list_pluck( $data, 'date_format' );
		$date_wise_enrolled = array_combine( $queried_date, $total );

		$results = array_merge( $datesPeriod, $date_wise_enrolled );
		foreach ( $results as $key => $TotalCount ) {
			unset( $results[ $key ] );
			$format_date             = gmdate( 'Y-m-d', strtotime( $key ) );
			$results[ $format_date ] = intval( $TotalCount );
		}
		return $results;
	}

	public function get_empty_collection_date_by_period( $begin, $end ) {
		$begin     = new \DateTime( $begin );
		$end       = new \DateTime( $end );
		$interval  = \DateInterval::createFromDateString( '1 day' );
		$period    = new \DatePeriod( $begin, $interval, $end );
		$day_lists = array();
		foreach ( $period as $value ) {
			$day_lists[ $value->format( 'Y-m-d' ) ] = 0;
		}
		return $day_lists;
	}
}
