<?php
namespace Academy\Frontend;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Academy;
use Academy\Classes\Query;

class Ajax {
	public static function init() {
		$self = new self();
		// lesson
		add_action( 'wp_ajax_academy/frontend/render_lesson', array( $self, 'render_lesson' ) );
		add_action( 'wp_ajax_nopriv_academy/frontend/render_lesson', array( $self, 'render_lesson' ) );
		add_action( 'wp_ajax_academy/frontend/mark_lesson_complete', array( $self, 'mark_lesson_complete' ) );
		add_action( 'wp_ajax_academy/frontend/render_enrolled_courses', array( $self, 'render_enrolled_courses' ) );
		add_action( 'wp_ajax_academy/frontend/render_pending_enrolled_courses', array( $self, 'render_pending_enrolled_courses' ) );
		add_action( 'wp_ajax_academy/frontend/render_wishlist_courses', array( $self, 'render_wishlist_courses' ) );
		add_action( 'wp_ajax_academy/frontend/render_popup_lesson', array( $self, 'render_popup_lesson' ) );
		add_action( 'wp_ajax_nopriv_academy/frontend/render_popup_lesson', array( $self, 'render_popup_lesson' ) );
		add_action( 'wp_ajax_nopriv_academy/frontend/course_add_to_wishlist', array( $self, 'course_add_to_wishlist' ) );
		add_action( 'wp_ajax_academy/frontend/course_add_to_wishlist', array( $self, 'course_add_to_wishlist' ) );
		add_action( 'wp_ajax_academy/frontend/course_add_to_favorite', array( $self, 'course_add_to_favorite' ) );
		add_action( 'wp_ajax_academy/frontend/saved_user_info', array( $self, 'saved_user_info' ) );
		add_action( 'wp_ajax_academy/frontend/reset_password', array( $self, 'reset_password' ) );
		add_action( 'wp_ajax_academy/frontend/get_user_given_reviews', array( $self, 'get_user_given_reviews' ) );
		add_action( 'wp_ajax_academy/frontend/get_user_received_reviews', array( $self, 'get_user_received_reviews' ) );
		add_action( 'wp_ajax_academy/frontend/get_user_purchase_history', array( $self, 'get_user_purchase_history' ) );
		add_action( 'wp_ajax_academy/frontend/archive_course_filter', array( $self, 'archive_course_filter' ) );
		add_action( 'wp_ajax_nopriv_academy/frontend/archive_course_filter', array( $self, 'archive_course_filter' ) );
		add_action( 'wp_ajax_academy/frontend/get_my_courses', array( $self, 'get_my_courses' ) );
		add_action( 'wp_ajax_nopriv_academy/frontend/render_popup_login', array( $self, 'render_popup_login' ) );
		add_action( 'wp_ajax_nopriv_academy/frontend/enroll_course', array( $self, 'enroll_course' ) );
		add_action( 'wp_ajax_academy/frontend/enroll_course', array( $self, 'enroll_course' ) );
		add_action( 'wp_ajax_academy/frontend/complete_course', array( $self, 'complete_course' ) );
		add_action( 'wp_ajax_academy/frontend/add_course_review', array( $self, 'add_course_review' ) );
	}

	public function render_lesson() {
		check_admin_referer( 'academy_nonce', 'security' );
		$course_id = (int) sanitize_text_field( $_POST['course_id'] );
		$lesson_id = (int) sanitize_text_field( $_POST['lesson_id'] );
		$user_id   = (int) get_current_user_id();

		$is_administrator = current_user_can( 'administrator' );
		$is_accessible = Academy\Helper::get_lesson_meta( $lesson_id, 'is_previewable' );
		$is_instructor    = \Academy\Helper::is_instructor_of_this_course( $user_id, $course_id );
		$enrolled         = \Academy\Helper::is_enrolled( $course_id, $user_id );
		$is_public_course = \Academy\Helper::is_public_course( $course_id );

		if ( $is_accessible || $is_administrator || $is_instructor || $enrolled || $is_public_course ) {
			$lesson = \Academy\Helper::get_lesson( $lesson_id );
			$lesson->lesson_title  = stripslashes( $lesson->lesson_title );
			$lesson->lesson_content  = [
				'raw' => stripslashes( $lesson->lesson_content ),
				'rendered' => \Academy\Helper::get_content_html( stripslashes( $lesson->lesson_content ) ),
			];
			$lesson->author_name = get_the_author_meta( 'display_name', $lesson->lesson_author );
			$lesson->meta            = \Academy\Helper::get_lesson_meta_data( $lesson_id );

			if ( empty( $lesson ) ) {
				wp_send_json_error( array( 'message' => __( 'Sorry, something went wrong!', 'academy' ) ) );
				wp_die();
			}

			do_action( 'academy/frontend/before_render_lesson', $lesson, $course_id, $lesson_id );

			if ( count( $lesson->meta ) > 0 ) {
				if ( isset( $lesson->meta['attachment'] ) && ! empty( $lesson->meta['attachment'] ) ) {
					$lesson->meta['attachment'] = wp_get_attachment_url( $lesson->meta['attachment'] );
				}
				if ( isset( $lesson->meta['video_source'] ) && ! empty( $lesson->meta['video_source'] ) ) {
					$video = $lesson->meta['video_source'];
					if ( 'html5' === $video['type'] && isset( $video['id'] ) ) {
						$attachment_id = (int) $video['id'];
						$att_url       = wp_get_attachment_url( $attachment_id );
						$video['url']  = $att_url;
					} elseif ( 'youtube' === $video['type'] ) {
						$video['url'] = \Academy\Helper::youtube_id_from_url( $video['url'] );
					} elseif ( 'vimeo' === $video['type'] ) {
						$video['url'] = \Academy\Helper::youtube_id_from_url( $video['url'] );
					} elseif ( 'embedded' === $video['type'] ) {
						$video['url'] = \Academy\Helper::parse_embedded_url( wp_unslash( $video['url'] ) );
					} elseif ( 'external' === $video['type'] ) {
						// first check external URL contain html5 video or not
						if ( \Academy\Helper::is_html5_video_link( $video['url'] ) ) {
							$video['type'] = 'html5';
							$embed_url = \Academy\Helper::get_basic_url_to_embed_url( $video['url'] );
							if ( isset( $embed_url['url'] ) && ! empty( $embed_url['url'] ) ) {
								$video['url'] = $embed_url['url'];
							}
						} else {
							$video['url'] = \Academy\Helper::get_basic_url_to_embed_url( $video['url'] );
						}
					} else {
						$video['type'] = 'external';
						$video['url'] = $video['url'];
					}//end if
					$lesson->meta['video_source'] = $video;
				}//end if
			}//end if
			wp_send_json_success( $lesson );
		}//end if
		wp_send_json_error( array( 'message' => __( 'Access Denied', 'academy' ) ) );
		wp_die();
	}

	public function mark_lesson_complete() {
		check_admin_referer( 'academy_nonce', 'security' );
		$course_id = (int) ( isset( $_POST['course_id'] ) ? sanitize_text_field( $_POST['course_id'] ) : '' );
		$topic_type = ( isset( $_POST['topic_type'] ) ? sanitize_text_field( $_POST['topic_type'] ) : '' );
		$topic_id = (int) ( isset( $_POST['topic_id'] ) ? sanitize_text_field( $_POST['topic_id'] ) : '' );
		$user_id   = (int) get_current_user_id();
		if ( empty( $topic_type ) || ! $course_id || ! $topic_id ) {
			wp_send_json_error( __( 'Request is not valid.', 'academy' ) );
		}
		$option_name = 'academy_course_' . $course_id . '_completed_topics';
		$saved_topics_lists = (array) json_decode( get_user_meta( $user_id, $option_name, true ), true );

		if ( isset( $saved_topics_lists[ $topic_type ][ $topic_id ] ) ) {
			unset( $saved_topics_lists[ $topic_type ][ $topic_id ] );
		} else {
			$saved_topics_lists[ $topic_type ][ $topic_id ] = \Academy\Helper::get_time();
		}
		$saved_topics_lists = wp_json_encode( $saved_topics_lists );
		update_user_meta( $user_id, $option_name, $saved_topics_lists );
		wp_send_json_success( $saved_topics_lists );
	}

	public function render_enrolled_courses() {
		check_admin_referer( 'academy_nonce', 'security' );
		$request_type = ( isset( $_POST['request_type'] ) ? sanitize_text_field( $_POST['request_type'] ) : 'enrolled' );
		$user_id = get_current_user_id();
		$enrolled_course_ids = \Academy\Helper::get_enrolled_courses_ids_by_user( $user_id );
		$complete_course_ids = \Academy\Helper::get_complete_courses_ids_by_user( $user_id );
		$post_in = $enrolled_course_ids;
		if ( 'complete' === $request_type ) {
			$post_in = $complete_course_ids;
		} elseif ( 'active' === $request_type ) {
			$post_in      = array_diff( $enrolled_course_ids, $complete_course_ids );
		}

		$course_args = array(
			'post_type'      => 'academy_courses',
			'post_status'    => 'publish',
			'post__in'       => $post_in,
			'posts_per_page' => -1,
		);
		$courses = new \WP_Query( $course_args );
		ob_start();
		?>
		<div class="academy-row"> 
			<?php
			if ( count( $post_in ) && $courses && $courses->have_posts() ) :
				while ( $courses->have_posts() ) :
					$courses->the_post();
					$ID                      = get_the_ID();
					$rating                  = \Academy\Helper::get_course_rating( $ID );
					$total_lessons           = \Academy\Helper::get_total_number_of_course_lessons( $ID );
					$total_completed_lessons = \Academy\Helper::get_total_number_of_completed_course_lessons( $ID );
					$percentage              = \Academy\Helper::calculate_percentage( $total_lessons, $total_completed_lessons );
					?>
			<div class="academy-col-lg-3 academy-col-md-6 academy-col-sm-12">
				<div class="academy-mycourse academy-mycourse-<?php the_ID(); ?>">
					<div class="academy-mycourse__thumbnail">
						<a href="<?php echo esc_url( get_the_permalink() ); ?>">
							<img class="academy-course__thumbnail-image" src="<?php echo esc_url( Academy\Helper::get_the_course_thumbnail_url( 'academy_thumbnail' ) ); ?>" alt="<?php esc_html_e( 'thumbnail', 'academy' ); ?>">
						</a>
					</div>
					<div class="academy-mycourse__content">
						<div class="academy-course__rating">
								<?php
									// phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
									echo \Academy\Helper::star_rating_generator( $rating->rating_avg );
								?>
								<?php echo esc_html( $rating->rating_avg ); ?> <span
								class="academy-course__rating-count"><?php echo esc_html( '(' . $rating->rating_count . ')' ); ?></span>
						</div>
						<h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
						<div class="academy-course__meta">
							<div class="academy-course__meta-item"><?php esc_html_e( 'Total Lessons:', 'academy' ); ?><span><?php echo esc_html( $total_lessons ); ?></span></div>
							<div class="academy-course__meta-item"><?php esc_html_e( 'Completed Lessons:', 'academy' ); ?><span><?php echo esc_html( $total_lessons . '/' . $total_completed_lessons ); ?></span>
							</div>
						</div>
						<div class="academy-progress-wrap">
							<div class="academy-progress">
								<div class="academy-progress-bar"
									style="width: <?php echo esc_attr( $percentage ) . '%'; ?>;">
								</div>
							</div>
							<span class="academy-progress-wrap__percent"><?php echo esc_html( $percentage ) . esc_html__( '%  Complete', 'academy' ); ?></span>
						</div>
						<?php
							\Academy\Helper::get_template( 'single-course/enroll/continue.php' );
						?>
					</div>
				</div>
			</div>
					<?php
				endwhile;
				?>
		</div>
				<?php

				wp_reset_query(); else : ?>
				<div class='academy-mycourse'>
					<h3 class='academy-not-found'>
						<?php
						if ( 'active' === $request_type ) {
							esc_html_e( 'You have no active courses.', 'academy' );
						} elseif ( 'complete' === $request_type ) {
							esc_html_e( 'You have no complete courses.', 'academy' );
						} else {
							esc_html_e( 'You are not enrolled in any course yet.', 'academy' );
						}
						?>
					</h3>
				</div>
					<?php
		endif;
				$output = ob_get_clean();
				wp_send_json_success( $output );
				wp_die();
	}

	public function render_pending_enrolled_courses() {
		check_admin_referer( 'academy_nonce', 'security' );
		$user_id = get_current_user_id();
		$pending_enrolled_course_ids = \Academy\Helper::get_pending_enrolled_courses_ids_by_user( $user_id );
		if ( ! count( $pending_enrolled_course_ids ) ) {
			wp_send_json_success( [] );
		}
		$course_args = array(
			'post_type'      => 'academy_courses',
			'post_status'    => 'publish',
			'post__in'       => $pending_enrolled_course_ids,
			'posts_per_page' => -1,
		);
		$courses = new \WP_Query( $course_args );
		$response = [];
		if ( count( $pending_enrolled_course_ids ) && $courses->have_posts() ) {
			while ( $courses->have_posts() ) :
				$courses->the_post();
				$response[] = array(
					'ID' => get_the_ID(),
					'permalink' => get_the_permalink(),
					'title' => get_the_title(),
				);
			endwhile;
			wp_reset_query();
		}
		wp_send_json_success( $response );
	}

	public function render_wishlist_courses() {
		check_admin_referer( 'academy_nonce', 'security' );

		$courses = \Academy\Helper::get_wishlist_courses_by_user( get_current_user_id(), array( 'private', 'publish' ) );

		ob_start();
		?>

<div class="academy-courses">
	<div class="academy-row">
		<?php
		if ( $courses && $courses->have_posts() ) :
			while ( $courses->have_posts() ) :
				$courses->the_post();
				\Academy\Helper::get_template_part( 'content', 'course' );
			endwhile;
			wp_reset_query();
		else :
			?>
		<div class='academy-mycourse'>
			<h3 class='academy-not-found'><?php esc_html_e( 'Your wishlist is empty!', 'academy' ); ?></h3>
		</div>
			<?php
			endif;
		?>
	</div>
</div>
		<?php
		$output = ob_get_clean();
		wp_send_json_success( $output );
		wp_die();
	}

	public function course_add_to_wishlist() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! is_user_logged_in() ) {
			if ( \Academy\Helper::get_settings( 'is_enabled_academy_login', true ) ) {
				ob_start();
				echo do_shortcode( '[academy_login_form form_title="' . esc_html__( 'Hi, Welcome back!', 'academy' ) . '" show_logged_in_message="false"]' );
				$markup = ob_get_clean();
				wp_send_json_error( array( 'markup' => $markup ) );
			}
			wp_send_json_error( array( 'redirect_to' => wp_login_url( wp_get_referer() ) ) );
		}

		global $wpdb;
		$course_id          = (int) sanitize_text_field( $_POST['course_id'] );
		$user_id            = get_current_user_id();
		$is_already_in_list = $wpdb->get_row( $wpdb->prepare( "SELECT * from {$wpdb->usermeta} WHERE user_id = %d AND meta_key = 'academy_course_wishlist' AND meta_value = %d;", $user_id, $course_id ) );
		if ( $is_already_in_list ) {
			$wpdb->delete(
				$wpdb->usermeta,
				array(
					'user_id'    => $user_id,
					'meta_key'   => 'academy_course_wishlist',
					'meta_value' => $course_id,
				)
			);
			wp_send_json_success( array( 'is_added' => false ) );
		}
		add_user_meta( $user_id, 'academy_course_wishlist', $course_id );
		wp_send_json_success( array( 'is_added' => true ) );
	}
	public function course_add_to_favorite() {
		check_admin_referer( 'academy_nonce', 'security' );
		global $wpdb;
		$course_id          = (int) sanitize_text_field( $_POST['course_id'] );
		$user_id            = get_current_user_id();
		$is_already_in_list = $wpdb->get_row( $wpdb->prepare( "SELECT * from {$wpdb->usermeta} WHERE user_id = %d AND meta_key = 'academy_course_favorite' AND meta_value = %d;", $user_id, $course_id ) );
		if ( $is_already_in_list ) {
			$wpdb->delete(
				$wpdb->usermeta,
				array(
					'user_id'    => $user_id,
					'meta_key'   => 'academy_course_favorite',
					'meta_value' => $course_id,
				)
			);
			wp_send_json_success( array( 'is_added' => false ) );
		}
		add_user_meta( $user_id, 'academy_course_favorite', $course_id );
		wp_send_json_success( array( 'is_added' => true ) );
	}
	public function saved_user_info() {
		check_admin_referer( 'academy_nonce', 'security' );
		$data    = \Academy\Helper::fresh_ajax_request_data( $_POST );
		$data    = \Academy\Helper::sanitize_text_or_array_field( $data );
		$user_id = get_current_user_id();
		foreach ( $data as $key => $value ) {
			update_user_meta( $user_id, $key, $value );
		}
		wp_send_json_success( $data );
		wp_die();
	}
	public function reset_password() {
		check_admin_referer( 'academy_nonce', 'security' );
		$message      = '';
		$data         = \Academy\Helper::fresh_ajax_request_data( $_POST );
		$data         = \Academy\Helper::sanitize_text_or_array_field( $data );
		$current_user = wp_get_current_user();
		if ( $current_user && wp_check_password( $data['current_password'], $current_user->data->user_pass, $current_user->ID ) ) {
			if ( ! empty( $data['new_password'] ) && $data['new_password'] === $data['confirm_new_password'] ) {
				$user = wp_get_current_user();
				// Change password.
				wp_set_password( $data['new_password'], $user->ID );
				// Log-in again.
				wp_set_auth_cookie( $user->ID );
				wp_set_current_user( $user->ID );
				do_action( 'wp_login', $user->user_login, $user );
				wp_send_json_success( esc_html__( 'Successfully, updated your password.', 'academy' ) );
				wp_die();
			} else {
				$message .= esc_html__( 'New Password and Confirm New password do not match equally.', 'academy' );
			}
		} else {
			$message .= esc_html__( 'Current password is incorrect.', 'academy' );
		}
		wp_send_json_error( $message );
		wp_die();
	}
	public function get_user_given_reviews() {
		check_admin_referer( 'academy_nonce', 'security' );
		$user_id = get_current_user_id();
		$reviews = \Academy\Helper::get_reviews_by_user( $user_id );
		$results = [];
		if ( is_array( $reviews ) ) {
			foreach ( $reviews as $review ) {
				$review->post_title     = get_the_title( $review->comment_post_ID );
				$review->post_permalink = esc_url( get_the_permalink( $review->comment_post_ID ) );
				$results[]              = $review;
			}
		}
		wp_send_json_success( $results );
		wp_die();
	}
	public function get_user_received_reviews() {
		check_admin_referer( 'academy_nonce', 'security' );
		$user_id = get_current_user_id();
		$reviews = \Academy\Helper::get_reviews_by_instructor( $user_id );
		$results = [];
		if ( is_array( $reviews ) ) {
			foreach ( $reviews as $review ) {
				$review->post_title     = get_the_title( $review->comment_post_ID );
				$review->post_permalink = esc_url( get_the_permalink( $review->comment_post_ID ) );
				$results[]              = $review;
			}
		}
		wp_send_json_success( $results );
		wp_die();
	}

	public function get_user_purchase_history() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! \Academy\Helper::is_active_woocommerce() ) {
			wp_die();
		}
		$user_id = get_current_user_id();
		$orders  = \Academy\Helper::get_orders_by_user_id( $user_id );
		$results = [];
		if ( is_array( $orders ) ) {
			foreach ( $orders as $order ) {
				$courses_order = \Academy\Helper::get_course_enrolled_ids_by_order_id( $order->ID );
				$courses       = [];
				if ( is_array( $courses_order ) ) {
					foreach ( $courses_order as $course ) {
						$courses[] = [
							'ID'        => $course['course_id'],
							'title'     => get_the_title( $course['course_id'] ),
							'permalink' => esc_url( get_the_permalink( $course['course_id'] ) ),
						];
					}
				}
				$wc_order  = wc_get_order( $order->ID );
				$price     = $wc_order->get_total();
				$status    = \Academy\Helper::order_status_context( $order->post_status );
				$results[] = [
					'ID'      => $order->ID,
					'courses' => $courses,
					'price'   => wc_price( $price, array( 'currency' => $wc_order->get_currency() ) ),
					'status'  => $status,
					'date'    => date_i18n( get_option( 'date_format' ), strtotime( $order->post_date ) ),
				];
			}//end foreach
		}//end if
		wp_send_json_success( $results );
		wp_die();
	}

	public function archive_course_filter() {
		check_admin_referer( 'academy_nonce', 'security' );

		$search   = ( isset( $_POST['search'] ) ? sanitize_text_field( $_POST['search'] ) : '' );
		$category = ( isset( $_POST['category'] ) ? \Academy\Helper::sanitize_text_or_array_field( $_POST['category'] ) : [] );
		$tags     = ( isset( $_POST['tags'] ) ? \Academy\Helper::sanitize_text_or_array_field( $_POST['tags'] ) : [] );
		$levels   = ( isset( $_POST['levels'] ) ? \Academy\Helper::sanitize_text_or_array_field( $_POST['levels'] ) : [] );
		$type     = ( isset( $_POST['type'] ) ? \Academy\Helper::sanitize_text_or_array_field( $_POST['type'] ) : [] );
		$orderby  = ( isset( $_POST['orderby'] ) ? sanitize_text_field( $_POST['orderby'] ) : 'DESC' );
		$paged    = ( isset( $_POST['paged'] ) ) ? absint( sanitize_text_field( $_POST['paged'] ) ) : 1;

		$args = \Academy\Helper::prepare_course_search_query_args(
			[
				'search'         => $search,
				'category'       => $category,
				'tags'           => $tags,
				'levels'         => $levels,
				'type'           => $type,
				'paged'          => $paged,
				'orderby'        => $orderby,
				'posts_per_page' => (int) \Academy\Helper::get_customizer_settings( 'course_per_page', 12 ),
			]
		);

		$courses = new \WP_Query( $args );
		ob_start();
		?>
		<div class="academy-row">
				<?php
				if ( $courses->have_posts() ) :
					while ( $courses->have_posts() ) :
						$courses->the_post();
						\Academy\Helper::get_template_part( 'content', 'course' );
				endwhile;
					wp_reset_query(); else :
						?>
			<div class='academy-mycourse'>
				<h3 class='academy-not-found'><?php esc_html_e( 'Sorry no course found.', 'academy' ); ?>
				</h3>
			</div>
				<?php endif; ?>
			<div class="academy-courses__pagination academy-col-md-12">
				<?php
				$big = 999999999;
				// phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				echo paginate_links(
					array(
						'base'      => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
						'format'    => '?paged=%#%',
						'current'   => max( 1, $paged ),
						'total'     => $courses->max_num_pages,
						'prev_text' => '<i class="academy-icon academy-icon--angle-left"></i>',
						'next_text' => '<i class="academy-icon academy-icon--angle-right"></i>',
					)
				);
				?>
			</div>
		</div>
		<?php
		$markup = ob_get_clean();
		wp_send_json_success(
			[
				'markup'      => $markup,
				'found_posts' => $courses->found_posts,
			]
		);
		wp_die();
	}

	public function get_my_courses() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( ! current_user_can( 'manage_academy_instructor' ) ) {
			wp_die();
		}

		$response = [];
		$course_args = array(
			'post_type'         => 'academy_courses',
			'post_status'       => 'publish',
			'author'            => get_current_user_id(),
			'posts_per_page'    => -1,
		);
		$courses = new \WP_Query( $course_args );
		if ( $courses->have_posts() ) :
			while ( $courses->have_posts() ) :
				$courses->the_post();
				$ID                      = get_the_ID();
				$rating                  = \Academy\Helper::get_course_rating( $ID );
				$rating_markup = \Academy\Helper::star_rating_generator( $rating->rating_avg );
				$total_enrolled = \Academy\Helper::count_course_enrolled( $ID );
				$response[] = array(
					'title'             => get_the_title( $ID ),
					'permalink'         => get_the_permalink( $ID ),
					'rating'            => $rating,
					'rating_markup'     => $rating_markup,
					'total_enrolled'    => $total_enrolled
				);
			endwhile;
			wp_reset_query();
		endif;
		wp_send_json_success( $response );
	}

	public function render_popup_login() {
		check_admin_referer( 'academy_nonce', 'security' );
		if ( is_user_logged_in() ) {
			wp_die();
		}
		$page_id = $_REQUEST['page_id'];
		$register_url = esc_url( add_query_arg( 'redirect_to', get_permalink( $page_id ), \Academy\Helper::get_page_permalink( 'frontend_student_reg_page' ) ) );
		ob_start();
		echo do_shortcode( '[academy_login_form form_title="' . esc_html__( 'Hi, Welcome back!', 'academy' ) . '" show_logged_in_message="false" student_register_url="' . $register_url . '"]' );
		$markup = ob_get_clean();
		wp_send_json_success( $markup );
	}
	public function enroll_course() {
		check_admin_referer( 'academy_nonce' );

		if ( ! is_user_logged_in() ) {
			wp_send_json_error( array( 'is_required_logged_in' => true ) );
		}

		$user_id = get_current_user_id();

		$course_id = (int) sanitize_text_field( $_POST['course_id'] );

		$is_enrolled = \Academy\Helper::do_enroll( $course_id, $user_id );
		if ( $is_enrolled ) {
			wp_send_json_success( __( 'Successfully Enrolled.', 'academy' ) );
		}
		wp_send_json_error( __( 'Failed to enrolled course.', 'academy' ) );
	}

	public function complete_course() {
		check_admin_referer( 'academy_nonce', 'security' );
		$user_id = get_current_user_id();
		$course_id = (int) sanitize_text_field( $_POST['course_id'] );
		$has_incomplete_topic = false;
		$curriculum_lists = \Academy\Helper::get_course_curriculum( $course_id );
		foreach ( $curriculum_lists as $curriculum_list ) {
			if ( is_array( $curriculum_list['topics'] ) ) {
				foreach ( $curriculum_list['topics'] as $topic ) {
					if ( empty( $topic['is_completed'] ) ) {
						$has_incomplete_topic = true;
						break;
					}
				}
			}
			// found incomplete topic then break loop
			if ( $has_incomplete_topic ) {
				break;
			}
		}

		if ( $has_incomplete_topic ) {
			wp_send_json_error( __( 'To complete this course, please make sure that you have finished all the topics.', 'academy' ) );
		}

		do_action( 'academy/admin/course_complete_before', $course_id );

		global $wpdb;
		$date = gmdate( 'Y-m-d H:i:s', \Academy\Helper::get_time() );

		// hash is unique.
		do {
			$hash    = substr( md5( wp_generate_password( 32 ) . $date . $course_id . $user_id ), 0, 16 );
			$hasHash = (int) $wpdb->get_var(
				$wpdb->prepare(
					"SELECT COUNT(comment_ID) from {$wpdb->comments} 
				WHERE comment_agent = 'academy' AND comment_type = 'course_completed' AND comment_content = %s ",
					$hash
				)
			);

		} while ( $hasHash > 0 );

		$data = array(
			'comment_post_ID'  => $course_id,
			'comment_author'   => $user_id,
			'comment_date'     => $date,
			'comment_date_gmt' => get_gmt_from_date( $date ),
			'comment_content'  => $hash,
			'comment_approved' => 'approved',
			'comment_agent'    => 'academy',
			'comment_type'     => 'course_completed',
			'user_id'          => $user_id,
		);
		$is_complete = $wpdb->insert( $wpdb->comments, $data );

		do_action( 'academy/admin/course_complete_after', $course_id, $user_id );

		if ( $is_complete ) {
			wp_send_json_success( __( 'Successfully Completed.', 'academy' ) );
		}
		wp_send_json_error( __( 'Failed, try again.', 'academy' ) );
	}
	public function add_course_review() {
		check_admin_referer( 'academy_nonce', 'security' );
		$course_id = (int) sanitize_text_field( $_POST['course_id'] );
		$user_id = get_current_user_id();
		$current_user = get_userdata( $user_id );

		if ( ! \Academy\Helper::is_completed_course( $course_id, $user_id ) ) {
			wp_send_json_error( __( 'Sorry, you have to complete the course first.', 'academy' ) );
		}

		$rating = (int) sanitize_text_field( $_POST['rating'] );
		$review = sanitize_text_field( $_POST['review'] );

		$data = array(
			'comment_post_ID'       => $course_id,
			'comment_content'       => $review,
			'user_id'               => $current_user->ID,
			'comment_author'        => $current_user->user_login,
			'comment_author_email'  => $current_user->user_email,
			'comment_author_url'    => $current_user->user_url,
			'comment_type'          => 'academy_courses',
			'comment_approved'      => '1',
			'comment_meta'          => array(
				'academy_rating'    => $rating,
			)
		);

		$has_current_review = current(get_comments(array(
			'comment_type' => 'academy_courses',
			'post_id' => $course_id
		)));
		if ( isset( $has_current_review->comment_ID ) && ! empty( $has_current_review->comment_ID ) ) {
			$data['comment_ID'] = $has_current_review->comment_ID;
			$is_update = wp_update_comment( $data );
			if ( $is_update ) {
				wp_send_json_success(array(
					'message'       => __( 'Successfully Updated Review.', 'academy' ),
					'redirect_url' => get_the_permalink( $course_id ),
				));
			}
		}
		$comment_id = wp_insert_comment( $data );
		if ( $comment_id ) {
			wp_send_json_success(array(
				'message'       => __( 'Successfully Added Review.', 'academy' ),
				'redirect_url' => get_the_permalink( $course_id ),
			));
		}
		wp_send_json_error( __( 'Sorry, Failed to add review.', 'academy' ) );
	}
}
