<?php
namespace  Academy\Shortcode;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class AcademyRegistration {

	public function __construct() {
		add_shortcode( 'academy_instructor_registration_form', array( $this, 'instructor_registration_form' ) );
		add_shortcode( 'academy_student_registration_form', array( $this, 'student_registration_form' ) );
		add_action( 'wp_ajax_nopriv_academy/shortcode/instructor_registration_form_handler', array( $this, 'instructor_registration_form_handler' ) );
		add_action( 'wp_ajax_nopriv_academy/shortcode/student_registration_form_handler', array( $this, 'student_registration_form_handler' ) );
	}
	public function instructor_registration_form() {
		ob_start();
		if ( apply_filters( 'academy/shortcode/instructor_registration_form_is_user_logged_in', is_user_logged_in() ) ) {
			$dashboard_page_id = (int) \Academy\Helper::get_settings( 'frontend_dashboard_page' );
			$user_id = get_current_user_id();
			$instructor_status = '';
			if ( get_user_meta( $user_id, 'is_academy_instructor', true ) ) {
				$instructor_status = get_user_meta( $user_id, 'academy_instructor_status', true );
			}
			\Academy\Helper::get_template( 'shortcode/logged-in-instructor.php', array(
				'dashboard_url'     => get_permalink( $dashboard_page_id ),
				'instructor_status' => $instructor_status,
			) );
		} else {
			\Academy\Helper::get_template( 'shortcode/instructor.php' );
		}
		return apply_filters( 'academy/shortcode/instructor', ob_get_clean() );
	}
	public function student_registration_form() {
		ob_start();
		if ( apply_filters( 'academy/shortcode/student_registration_form_is_user_logged_in', is_user_logged_in() ) ) {
			$dashboard_page_id = (int) \Academy\Helper::get_settings( 'frontend_dashboard_page' );
			\Academy\Helper::get_template( 'shortcode/logged-in-student.php', array( 'dashboard_url' => get_permalink( $dashboard_page_id ) ) );
		} else {
			\Academy\Helper::get_template( 'shortcode/student.php' );
		}
		return apply_filters( 'academy/shortcode/student', ob_get_clean() );
	}

	public function instructor_registration_form_handler() {
		if ( wp_verify_nonce( $_POST['_wpnonce'], 'academy_instructor_registration_nonce' ) ) {
			if ( ! get_option( 'users_can_register' ) ) {
				wp_send_json_error( [ esc_html__( 'Sorry, Admin disabled new user registration', 'academy' ) ] );
			}
			$error = array();
			$redirect_to      = sanitize_text_field( $_POST['redirect_to'] );
			$first_name       = sanitize_text_field( $_POST['first_name'] );
			$last_name        = sanitize_text_field( $_POST['last_name'] );
			$user_name        = sanitize_text_field( $_POST['user_name'] );
			$email            = sanitize_text_field( $_POST['email'] );
			$password         = sanitize_text_field( $_POST['password'] );
			$confirm_password = sanitize_text_field( $_POST['confirm_password'] );

			if ( empty( $user_name ) ) {
				$error['username'] = __( 'You have used an invalid username.', 'academy' );
			} elseif ( username_exists( $user_name ) ) {
				$error['username'] = __( 'Invalid username provided or the username already registered.', 'academy' );
			}

			if ( empty( $email ) || ! is_email( $email ) ) {
				$error['email'] = __( 'Email is missing or Invalid.', 'academy' );
			} elseif ( email_exists( $email ) ) {
				$error['email'] = __( 'The provided email is already registered with other account. Please login or reset password or use another email.', 'academy' );
			}

			if ( empty( $password ) || empty( $confirm_password ) ) {
				$error['password'] = __( 'Your password is invalid.', 'academy' );
			} elseif ( $password !== $confirm_password ) {
				$error['password'] = __( 'Your confirmed password did not match.', 'academy' );
			}

			if ( count( $error ) ) {
				wp_send_json_error( $error );
			}

			$user_data = array(
				'user_login' => $user_name,
				'user_email' => $email,
				'first_name' => $first_name,
				'last_name'  => $last_name,
				'user_pass'  => $password,
			);
			do_action( 'academy/shortcode/before_instructor_registration', $user_data );

			$user_id = wp_insert_user( $user_data );
			if ( ! is_wp_error( $user_id ) ) {
				update_user_meta( $user_id, 'is_academy_instructor', \Academy\Helper::get_time() );
				update_user_meta( $user_id, 'academy_instructor_status', apply_filters( 'academy/admin/registration_instructor_status', 'pending' ) );

				do_action( 'academy/shortcode/after_instructor_registration', $user_id );

				$user = get_user_by( 'id', $user_id );
				if ( $user ) {
					wp_set_current_user( $user_id, $user->user_login );
					wp_set_auth_cookie( $user_id );
				}
			}

			$referer_url = $redirect_to ? $redirect_to : home_url( wp_get_referer() );

			wp_send_json_success([
				'message' => __( 'Registration completed successfully. Redirecting...', 'academy' ),
				'redirect_url' => esc_url( $referer_url )
			]);
			wp_send_json_success( $referer_url );
		}//end if
		wp_send_json_error( [ __( 'Security check', 'academy' ) ] );
	}

	public function student_registration_form_handler() {
		if ( wp_verify_nonce( $_POST['_wpnonce'], 'academy_student_registration_nonce' ) ) {
			if ( ! get_option( 'users_can_register' ) ) {
				wp_send_json_error( [ esc_html__( 'Sorry, Admin disabled new user registration', 'academy' ) ] );
			}
			$error = array();
			$redirect_to      = sanitize_text_field( $_POST['redirect_to'] );
			$first_name       = sanitize_text_field( $_POST['first_name'] );
			$last_name        = sanitize_text_field( $_POST['last_name'] );
			$user_name        = sanitize_text_field( $_POST['user_name'] );
			$email            = sanitize_text_field( $_POST['email'] );
			$password         = sanitize_text_field( $_POST['password'] );
			$confirm_password = sanitize_text_field( $_POST['confirm_password'] );

			if ( empty( $user_name ) ) {
				$error['username'] = __( 'You have used an invalid username.', 'academy' );
			} elseif ( username_exists( $user_name ) ) {
				$error['username'] = __( 'Invalid username provided or the username already registered.', 'academy' );
			}

			if ( empty( $email ) || ! is_email( $email ) ) {
				$error['email'] = __( 'Email is missing or Invalid.', 'academy' );
			} elseif ( email_exists( $email ) ) {
				$error['email'] = __( 'The provided email is already registered with other account. Please login or reset password or use another email.', 'academy' );
			}

			if ( empty( $password ) || empty( $confirm_password ) ) {
				$error['password'] = __( 'Your password is invalid.', 'academy' );
			} elseif ( $password !== $confirm_password ) {
				$error['password'] = __( 'Your confirmed password did not match.', 'academy' );
			}

			if ( count( $error ) ) {
				wp_send_json_error( $error );
			}

			$user_data = array(
				'user_login' => $user_name,
				'user_email' => $email,
				'first_name' => $first_name,
				'last_name'  => $last_name,
				'user_pass'  => $password,
				'role'       => 'academy_student',
			);
			do_action( 'academy/shortcode/before_student_registration', $user_data );

			$user_id = wp_insert_user( $user_data );
			if ( ! is_wp_error( $user_id ) ) {
				do_action( 'academy/shortcode/after_student_registration', $user_id );

				update_user_meta( $user_id, 'is_academy_student', \Academy\Helper::get_time() );
				$user = get_user_by( 'id', $user_id );
				if ( $user ) {
					wp_set_current_user( $user_id, $user->user_login );
					wp_set_auth_cookie( $user_id );
				}
			}
			$referer_url = $redirect_to ? $redirect_to : home_url( wp_get_referer() );

			wp_send_json_success([
				'message' => __( 'Registration completed successfully. Redirecting...', 'academy' ),
				'redirect_url' => esc_url( $referer_url )
			]);
			wp_send_json_success( $referer_url );
		}//end if
		wp_send_json_error( [ __( 'Security check', 'academy' ) ] );
	}
}
