<?php
namespace Academy\Traits;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

trait Instructor {

	public static function get_author() {
		global $wp_query;
		$user = get_user_by( 'login', $wp_query->query['author_name'] );
		return $user;
	}

	public static function get_the_author_id() {
		$user = self::get_author();
		if ( ! empty( $user ) ) {
			return $user->ID;
		}
		return null;
	}
	public static function get_the_author_name( $user_id = null ) {
		if ( null === $user_id ) {
			return;
		}
		$first_name = get_the_author_meta( 'first_name', $user_id );
		$last_name  = get_the_author_meta( 'last_name', $user_id );
		$nickname   = get_the_author_meta( 'nickname', $user_id );
		if ( $first_name || $last_name ) {
			return $first_name . ' ' . $last_name;
		}
		return $nickname;
	}
	public static function get_the_author_info( $user_id = null ) {
		if ( null === $user_id ) {
			return;
		}
		$profile_bio = get_the_author_meta( 'academy_profile_bio', $user_id );
		if ( $profile_bio ) {
			return $profile_bio;
		}
		return get_the_author_meta( 'description', $user_id );
	}
	public static function get_the_author_thumbnail_url( $user_id = null ) {
		if ( null === $user_id ) {
			return;
		}
		$profile_photo = get_the_author_meta( 'academy_profile_photo', $user_id );
		if ( $profile_photo ) {
			return $profile_photo;
		}
		return get_avatar_url(
			$user_id,
			[
				'size' => 250,
			]
		);
	}
	public static function get_all_instructors( $offset = 0, $per_page = 10, $search_keyword = '' ) {
		global $wpdb;
		$query = $wpdb->prepare(
			"SELECT ID, display_name, user_nicename, user_email
			FROM {$wpdb->users}
			INNER JOIN {$wpdb->usermeta}
			ON ({$wpdb->users}.ID = {$wpdb->usermeta}.user_id)
			WHERE {$wpdb->usermeta}.meta_key = %s",
		'is_academy_instructor');

		if ( ! empty( $search_keyword ) ) {
			$wild = '%';
			$like = $wild . $wpdb->esc_like( $search_keyword ) . $wild;
			$query .= $wpdb->prepare( 'AND (display_name LIKE %s OR user_nicename LIKE %s OR user_email LIKE %s)', $like, $like, $like );
		}
		$query .= $wpdb->prepare( ' LIMIT %d, %d;', $offset, $per_page );
		// phpcs:ignore 
		$results = $wpdb->get_results( $query );
		return $results;
	}
	public static function get_all_approved_instructors() {
		global $wpdb;
		$results = $wpdb->get_results(
			$wpdb->prepare(
				"SELECT ID, display_name, user_nicename, user_email
			FROM 	{$wpdb->users} 
				INNER JOIN {$wpdb->usermeta} 
					ON ( {$wpdb->users}.ID = {$wpdb->usermeta}.user_id )
			WHERE   {$wpdb->usermeta}.meta_key = %s AND 
                    {$wpdb->usermeta}.meta_value = %s;",
				'academy_instructor_status',
				'approved'
			)
		);
		if ( count( $results ) ) {
			return $results;
		}
		return false;
	}
	public static function get_current_instructor() {
		global $wpdb;
		$user_id = get_current_user_id();
		$results = $wpdb->get_results(
			$wpdb->prepare(
				"SELECT ID, display_name, user_nicename, user_email
			FROM 	{$wpdb->users} 
                INNER JOIN {$wpdb->usermeta} 
						ON ( {$wpdb->users}.ID = {$wpdb->usermeta}.user_id )
			WHERE   {$wpdb->users}.ID = %d AND {$wpdb->usermeta}.meta_key = %s;",
				$user_id,
				'is_academy_instructor'
			)
		);
		if ( count( $results ) ) {
			return $results;
		}
		return false;
	}
	public static function prepare_all_instructors_response( $instructors ) {
		$results = [];
		if ( is_array( $instructors ) ) {
			foreach ( $instructors as $instructor ) {
				$courseIds = \Academy\Helper::get_course_ids_by_instructor_id( $instructor->ID );
				$instructor->first_name        = get_user_meta( $instructor->ID, 'first_name', true );
				$instructor->last_name         = get_user_meta( $instructor->ID, 'last_name', true );
				$instructor->instructor_status = get_user_meta( $instructor->ID, 'academy_instructor_status', true );
				$instructor->total_courses     = is_array( $courseIds ) ? count( $courseIds ) : 0;
				$instructor->permalink         = get_edit_user_link( $instructor->ID );
				$results[]                     = $instructor;
			}
		}
		return array_reverse( $results );
	}

	public static function set_instructor_role( $user_id ) {
		update_user_meta( $user_id, 'is_academy_instructor', \Academy\Helper::get_time() );
		update_user_meta( $user_id, 'academy_instructor_status', 'approved' );
		update_user_meta( $user_id, 'academy_instructor_approved', \Academy\Helper::get_time() );
		$instructor = new \WP_User( $user_id );
		$instructor->add_role( 'academy_instructor' );
	}
	public static function pending_instructor_role( $user_id ) {
		update_user_meta( $user_id, 'academy_instructor_status', 'pending' );
		delete_user_meta( $user_id, 'academy_instructor_approved' );
		$instructor = new \WP_User( $user_id );
		$instructor->remove_role( 'academy_instructor' );
	}
	public static function remove_instructor_role( $user_id ) {
		delete_user_meta( $user_id, 'is_academy_instructor' );
		delete_user_meta( $user_id, 'academy_instructor_status' );
		delete_user_meta( $user_id, 'academy_instructor_approved' );
		$instructor = new \WP_User( $user_id );
		$instructor->remove_role( 'academy_instructor' );
	}
}
