<?php
namespace Academy\Traits;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

trait Lessons {

	public static function get_lesson( $ID ) {
		global $wpdb;
		$lesson  = $wpdb->get_results( $wpdb->prepare( "SELECT * FROM {$wpdb->prefix}academy_lessons WHERE ID=%d", $ID ), OBJECT );
		return current( $lesson );
	}
	public static function get_lesson_meta_data( $ID ) {
		global $wpdb;
		$meta_data = [];
		$results = $wpdb->get_results( $wpdb->prepare( "SELECT meta_key, meta_value FROM {$wpdb->prefix}academy_lessonmeta WHERE lesson_id=%d", $ID ), OBJECT );
		foreach ( $results as $result ) {
			$meta_data[ $result->meta_key ] = json_decode( $result->meta_value, true );
		}
		return $meta_data;
	}
	public static function get_lesson_meta( $ID, $meta_key ) {
		global $wpdb;
		$lesson_meta = current( $wpdb->get_results( $wpdb->prepare( "SELECT meta_key, meta_value FROM {$wpdb->prefix}academy_lessonmeta WHERE lesson_id=%d AND meta_key=%s", $ID, $meta_key ), OBJECT ) );
		if ( $lesson_meta ) {
			return json_decode( $lesson_meta->meta_value, true );
		}
		return null;
	}

	public static function get_lesson_video_duration( $lesson_id ) {
		if ( $lesson_id ) {
			$video_duration = \Academy\Helper::get_lesson_meta( $lesson_id, 'video_duration' );
			if ( is_array( $video_duration ) && ( $video_duration['hours'] || $video_duration['minutes'] || $video_duration['seconds'] ) ) {
				$video_duration = array_map(function ( $number ) {
					return sprintf( '%02d', $number );
				}, $video_duration);
				return implode( ':', $video_duration );
			}
			return '';
		}
		return '';
	}

	public static function get_total_number_of_lessons_by_instructor( $instructor_id ) {
		global $wpdb;
		$count = $wpdb->get_var(
			$wpdb->prepare(
				"SELECT COUNT(ID)
			FROM {$wpdb->prefix}academy_lessons lessons 
			WHERE lessons.lesson_author = %d AND lesson_status = %s
			",
				$instructor_id,
				'publish'
			)
		);
		return (int) $count;
	}
	public static function get_total_number_of_lessons() {
		global $wpdb;
		return $wpdb->get_var( "SELECT COUNT(*) FROM {$wpdb->prefix}academy_lessons" );
	}
}
