<?php
namespace Academy\Traits;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

trait Student {
	public static function get_all_students( $offset = 0, $per_page = 10, $search_keyword = '' ) {
		global $wpdb;
		$query = $wpdb->prepare(
			"SELECT ID, display_name, user_nicename, user_email
			FROM {$wpdb->users}
			INNER JOIN {$wpdb->usermeta}
			ON ({$wpdb->users}.ID = {$wpdb->usermeta}.user_id)
			WHERE {$wpdb->usermeta}.meta_key = %s",
		'is_academy_student');

		if ( ! empty( $search_keyword ) ) {
			$wild = '%';
			$like = $wild . $wpdb->esc_like( $search_keyword ) . $wild;
			$query .= $wpdb->prepare( 'AND (display_name LIKE %s OR user_nicename LIKE %s OR user_email LIKE %s)', $like, $like, $like );
		}
		$query .= $wpdb->prepare( ' ORDER BY ID DESC LIMIT %d, %d;', $offset, $per_page );
		// phpcs:ignore 
		$results = $wpdb->get_results( $query );
		return $results;
	}

	public static function prepare_get_all_students_response( $students ) {
		if ( ! is_array( $students ) ) {
			return;
		}

		$results = [];
		foreach ( $students as $student ) {
			$completed_courses_ids = self::get_completed_courses_ids_by_user( $student->ID );
			$enrolled_courses_ids = self::get_enrolled_courses_ids_by_user( $student->ID );

			if ( is_array( $completed_courses_ids ) && count( $completed_courses_ids ) > 0 ) {
				$completed_courses = [];
				foreach ( $completed_courses_ids as $courses_id ) {
					$completed_courses[ $courses_id ] = [
						'ID'     => $courses_id,
						'title'     => get_the_title( $courses_id ),
						'permalink' => get_the_permalink( $courses_id ),
					];
				}
				$student->completed_courses = array_values( $completed_courses );
			}

			if ( is_array( $enrolled_courses_ids ) && count( $enrolled_courses_ids ) > 0 ) {
				$enrolled_courses = [];
				foreach ( $enrolled_courses_ids as $courses_id ) {
					$title = get_the_title( $courses_id );
					if ( $title ) {
						$enrolled_courses[ $courses_id ] = [
							'ID'     => $courses_id,
							'title'     => get_the_title( $courses_id ),
							'permalink' => get_the_permalink( $courses_id ),
						];
					}
				}
				$student->enrolled_courses = array_values( $enrolled_courses );
			}

			$results[] = $student;
		}//end foreach
		return $results;
	}

	public static function set_student_role( $user_id ) {
		update_user_meta( $user_id, 'is_academy_student', \Academy\Helper::get_time() );
		$instructor = new \WP_User( $user_id );
		$instructor->add_role( 'academy_student' );
	}
}
